###################################
MKS Instruments Abstract Instrument
###################################

.. autoclass:: pymeasure.instruments.mksinst.mksinst.MKSInstrument
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.mksinst.mksinst.RelayChannel
    :members:
    :show-inheritance:
